@@ -1,8 +1,8 @@
 from time import sleep
 
 import pytest
-from pkg_resources import parse_version as v
 
+from qbittorrentapi._version_support import v
 from qbittorrentapi.rss import RSSitemsDictionary
 from tests.conftest import check
 from tests.conftest import get_func
@@ -10,9 +10,9 @@ from tests.conftest import get_func
 folder_one = "testFolderOne"
 folder_two = "testFolderTwo"
 
-item_one = "DistroWatch"
-item_two = "DistroWatchNew"
-url = "https://distrowatch.com/news/torrents.xml"
+item_one = "YTS"
+item_two = "YTSNew"
+url = "https://yts.mx/rss/0/all/all/0/en"
 
 
 def test_refresh_item(client, api_version, rss_feed):
